@@ -22,6 +22,11 @@ SUPPORT_SET_POSITION = 4
 SUPPORT_STOP = 8
 
 
+def patch_version(apiLevel):
+    """Helper function for generate a patch for a JSON state fixture."""
+    return f"""{{ "device": {{ "apiLevel": {apiLevel} }} }}"""
+
+
 class BleBoxCoverEntity(CommonEntity):
     """Representation of a BleBox cover feature."""
 
@@ -50,6 +55,7 @@ class BleBoxCoverEntity(CommonEntity):
         types = {
             "shutter": DEVICE_CLASS_SHUTTER,
             "gatebox": DEVICE_CLASS_DOOR,
+            "gateboxb": DEVICE_CLASS_DOOR,
             "gate": DEVICE_CLASS_DOOR,
         }
         return types[self._feature.device_class]
@@ -155,10 +161,6 @@ class TestShutter(CoverTest):
     """
     )
 
-    def patch_version(apiLevel):
-        """Generate a patch for a JSON state fixture."""
-        return f"""{{ "device": {{ "apiLevel": {apiLevel} }} }}"""
-
     DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20190912))
     DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20190911))
     DEVICE_INFO_OUTDATED = jmerge(DEVICE_INFO, patch_version(20190910))
@@ -469,6 +471,104 @@ class TestGateBox(CoverTest):
             await entity.async_set_cover_position(**{ATTR_POSITION: 1})  # almost closed
 
 
+class TestGateBoxB(CoverTest):
+    """Tests for cover devices representing a BleBox gateBoxB subgroup."""
+
+    DEV_INFO_PATH = "state"
+
+    DEVICE_INFO = json.loads(
+        """
+        {
+            "device": {
+                "deviceName":"My gateBox 1",
+                "type":"gateBox",
+                "product":"gateBox",
+                "hv":"9.1d",
+                "fv":"0.1010",
+                "universe":0,
+                "apiLevel":"20200831",
+                "id":"1afe34d27e4f",
+                "ip":"192.168.4.1",
+                "availableFv":null
+            }
+        }
+        """
+    )
+
+    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20210200))
+    DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20210118))
+
+    DEVICE_INFO_OUTDATED = DEVICE_INFO
+    DEVICE_INFO_MINIMUM = DEVICE_INFO
+    DEVICE_INFO_UNSUPPORTED = DEVICE_INFO
+
+    DEVICE_INFO_UNSPECIFIED_API = None  # already handled as default case
+
+    STATE_DEFAULT = json.loads(
+        """
+        {
+            "gate": {"currentPos": 0}
+        }
+        """
+    )
+
+    STATE_CLOSED = STATE_DEFAULT
+    STATE_STOPPED = jmerge(STATE_DEFAULT, '{"gate": {"currentPos": 50 }}')
+    STATE_FULLY_OPENED = jmerge(STATE_DEFAULT, '{"gate": {"currentPos": 100 }}')
+
+    async def test_unsupported_version(self, aioclient_mock):
+        """
+        Test version support. We don't need this - why is it written like that ?
+        What is the connection between api_level of the product and it's api_level_range ?
+        If api_level won't be in range of api_level_range then it will be using gateBox
+        class, not gateBoxB class.
+        """
+
+    async def test_init(self, aioclient_mock):
+        """Test cover default state."""
+
+        await self.allow_get_info(aioclient_mock)
+        entity = (await self.async_entities(aioclient_mock))[0]
+
+        assert entity.name == "My gateBox 1 (gateBoxB#position)"
+        assert entity.unique_id == "BleBox-gateBoxB-1afe34d27e4f-position"
+        assert entity.device_class == DEVICE_CLASS_DOOR
+        assert entity.supported_features & SUPPORT_OPEN
+        assert entity.supported_features & SUPPORT_CLOSE
+        assert entity.current_cover_position is None
+        self.assert_state(entity, None)
+
+    async def test_device_info(self, aioclient_mock):
+        """Test device info state."""
+
+        await self.allow_get_info(aioclient_mock, self.DEVICE_INFO)
+        entity = (await self.async_entities(aioclient_mock))[0]
+
+        assert entity.device_info["name"] == "My gateBox 1"
+        assert entity.device_info["mac"] == "1afe34d27e4f"
+        assert entity.device_info["manufacturer"] == "BleBox"
+        assert entity.device_info["model"] == "gateBoxB"
+        assert entity.device_info["sw_version"] == "0.1010"
+
+    async def test_fully_opened(self, aioclient_mock):
+        """Test cover fully opened."""
+
+        entity = await self.updated(aioclient_mock, self.STATE_FULLY_OPENED)
+        assert entity.state == STATE_OPEN
+
+    async def test_stop(self, aioclient_mock):
+        """Test cover stopped."""
+
+        entity = await self.updated(aioclient_mock, self.STATE_STOPPED)
+        self.assert_state(entity, STATE_OPEN)
+
+    async def test_closed(self, aioclient_mock):
+        """Test cover closed."""
+
+        entity = await self.updated(aioclient_mock, self.STATE_CLOSED)
+        self.assert_state(entity, STATE_CLOSED)
+
+
 class TestGateController(CoverTest):
     """Tests for cover devices representing a BleBox gateController."""
 
@@ -490,12 +590,6 @@ class TestGateController(CoverTest):
     """
     )
 
-    def patch_version(apiLevel):
-        """Generate a patch for a JSON state fixture."""
-        return f"""
-        {{ "device": {{ "apiLevel": {apiLevel} }} }}
-        """
-
     DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20190912))
     DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20190911))
     DEVICE_INFO_OUTDATED = jmerge(DEVICE_INFO, patch_version(20190910))
